@@ -4,10 +4,8 @@ package Data::Frame::Indexer;
 
 use Data::Frame::Setup;
 
-use Types::PDL qw(Piddle1D);
-
-use Data::Frame::Indexer::ByIndex;
-use Data::Frame::Indexer::ByLabel;
+use Data::Frame::Indexer::Integer;
+use Data::Frame::Indexer::Label;
 use Data::Frame::Types qw(:all);
 use Data::Frame::Util qw(is_discrete);
 
@@ -31,14 +29,14 @@ fun _as_indexer ($fallback_indexer_class) {
             $x = [$x];
         }
         if ( $NumericIndices->check($x) ) {
-            return Data::Frame::Indexer::ByIndex->new( indexer => $x->unpdl );
+            return Data::Frame::Indexer::Integer->new( indexer => $x->unpdl );
         }
         $fallback_indexer_class->new( indexer => $x );
     };
 }
 
-*indexer_s  = _as_indexer('Data::Frame::Indexer::ByLabel');
-*indexer_i = _as_indexer('Data::Frame::Indexer::ByIndex');
+*indexer_s  = _as_indexer('Data::Frame::Indexer::Label');
+*indexer_i = _as_indexer('Data::Frame::Indexer::Integer');
 
 1;
 
@@ -54,7 +52,7 @@ Data::Frame::Indexer - Function interface for indexer
 
 =head1 VERSION
 
-version 0.004_002
+version 0.004_003
 
 =head1 DESCRIPTION
 
@@ -87,13 +85,13 @@ If the argument is an indexer object, just returns it.
 
 If the argument is a PDL of numeric types, create an indexer object
 
-of L<Data::Frame::Indexer::ByIndex> 
+of L<Data::Frame::Indexer::Integer> 
 
 =item *
 
 Fallbacks to create an indexer object of
 
-L<Data::Frame::Indexer::ByLabel>.
+L<Data::Frame::Indexer::Label>.
 
 =back
 
@@ -102,7 +100,7 @@ L<Data::Frame::Indexer::ByLabel>.
     indexer_i($x)
 
 Similar to C<indexer_s> but would fallback to an indexer object of
-L<Data::Frame::Indexer::ByIndex>.
+L<Data::Frame::Indexer::Integer>.
 
 =head1 AUTHORS
 
